@@ -121,16 +121,16 @@ class SqlCreds:
             # get the odbc url part from the engine, split by ';' delimiter
             conn_url = engine.url.query["odbc_connect"].split(";")
             # convert into dict
-            conn_dict = {x.split("=")[0]: x.split("=")[1] for x in conn_url if "=" in x}
+            conn_dict = {x.split("=")[0].lower(): x.split("=")[1] for x in conn_url if "=" in x}
 
-            if "," in conn_dict["Server"]:
-                conn_dict["port"] = int(conn_dict["Server"].split(",")[1])
+            if "," in conn_dict["server"]:
+                conn_dict["port"] = int(conn_dict["server"].split(",")[1])
 
             sql_creds = cls(
-                server=conn_dict["Server"].replace("tcp:", "").split(",")[0],
-                database=conn_dict["Database"],
-                username=conn_dict.get("UID", None),
-                password=conn_dict.get("PWD", None),
+                server=conn_dict["server"].replace("tcp:", "").split(",")[0],
+                database=conn_dict["database"],
+                username=conn_dict.get("uid", None),
+                password=conn_dict.get("pwd", None),
                 port=conn_dict.get("port", None),
             )
 
@@ -322,6 +322,7 @@ def to_sql(
     print_output: bool = True,
     delimiter: str = None,
     quotechar: str = None,
+    encoding: Optional[str] = None,
 ):
     """
     Writes the pandas DataFrame to a SQL table or view.
@@ -374,6 +375,8 @@ def to_sql(
         Optional delimiter to use, otherwise will use the result of `constants.get_delimiter`
     quotechar: str, default None
         Optional quotechar to use, otherwise will use the result of `constants.get_quotechar`
+    encoding: str, default None
+        Optional encoding to use for writing the BCP data-file. Defaults to `utf-8`.
 
     Notes
     -----
@@ -406,6 +409,7 @@ def to_sql(
         line_terminator=NEWLINE,
         doublequote=True,
         escapechar=None,  # not needed, as using doublequote
+        encoding=encoding,
     )
     logger.debug(f"Saved dataframe to temp CSV file at {csv_file_path}")
 
