@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Created on Sat Aug  3 23:36:07 2019
 
@@ -26,8 +25,7 @@ import sqlalchemy
 
 from bcpandas import to_sql
 from bcpandas.constants import _DELIMITER_OPTIONS, _QUOTECHAR_OPTIONS, BCPandasValueError
-
-from .utils import (
+from bcpandas.tests.utils import (
     assume_not_all_delims_and_quotechars,
     df_hypo_dates,
     df_hypo_floats,
@@ -195,9 +193,9 @@ def test_tosql_empty_df(df, sql_creds):
     to_sql(df=df, table_name=tbl_name, creds=sql_creds, schema=schema_name, if_exists="replace")
     # make sure nothing happened in the database
     qry = """
-        SELECT * 
-        FROM INFORMATION_SCHEMA.TABLES 
-        WHERE TABLE_SCHEMA = '{_schema}' 
+        SELECT *
+        FROM INFORMATION_SCHEMA.TABLES
+        WHERE TABLE_SCHEMA = '{_schema}'
         AND TABLE_NAME = '{_tbl}'
         """.format(
         _tbl=tbl_name, _schema=schema_name
@@ -652,7 +650,7 @@ class TestToSqlDtypeScenarios(_BaseToSql):
               DATA_TYPE,
               CHARACTER_MAXIMUM_LENGTH
             FROM
-              INFORMATION_SCHEMA.COLUMNS 
+              INFORMATION_SCHEMA.COLUMNS
             WHERE
               TABLE_NAME = '{self.table_name}'""",
             con=self.pyodbc_creds,
@@ -690,7 +688,7 @@ class TestToSqlDtypeScenarios(_BaseToSql):
               DATA_TYPE,
               CHARACTER_MAXIMUM_LENGTH
             FROM
-              INFORMATION_SCHEMA.COLUMNS 
+              INFORMATION_SCHEMA.COLUMNS
             WHERE
               TABLE_NAME = '{self.table_name}'""",
             con=self.pyodbc_creds,
