@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Created on Sat Aug  3 23:07:15 2019
 
@@ -17,7 +16,7 @@ from typing import Dict, List, Optional, Union
 
 import pandas as pd
 
-from .constants import (
+from bcpandas.constants import (
     DIRECTIONS,
     IN,
     IS_WIN32,
